fillWidth property
Align the first and last points of the chart with both ends.
Can only be set to true if onChange is null.
Implementation
final bool fillWidth;
Align the first and last points of the chart with both ends.
Can only be set to true if onChange is null.
final bool fillWidth;