getYAxisTickLineHeight property
Get Y-axis tick line height from the length of _yAxis.
Calculate by subtracting dy from
SlidableLineChart.coordinateSystemOrigin.
Implementation
final GetYAxisTickLineHeight getYAxisTickLineHeight;
Get Y-axis tick line height from the length of _yAxis.
Calculate by subtracting dy from
SlidableLineChart.coordinateSystemOrigin.
final GetYAxisTickLineHeight getYAxisTickLineHeight;