max property

int max
final

The maximum value that the user can slide to.

Must be greater than or equal to min.

Generate SlidableLineChartState._yAxis from this value and min, divisions.

This value is not necessarily the maximum value actually display on the Y-axis.

Y-axis generation is also affected by reversed and onlyRenderEvenAxisLabel,

See SlidableLineChartState._generateYAxis.

Implementation

final int max;