min property

int min
final

The minimum value that the user can slide to.

Must be less than or equal to max.

Generate SlidableLineChartState._yAxis from this value and max, divisions.

This value is also the start value for the Y-axis.

Y-axis generate is also affected by reversed and onlyRenderEvenAxisLabel,

See SlidableLineChartState._generateYAxis.

Implementation

final int min;