onDrawCheckOrClose property

OnDrawIndicator? onDrawCheckOrClose
final

Called when the user slides coordinate, the return value determines the indicator type.

The return value is used to draw a check or close indicator below the coordinate system.

Defaults to null, nothing.

See CoordinateSystemPainter._drawCoordinates.

Implementation

final OnDrawIndicator? onDrawCheckOrClose;