positionPadding property

EdgeInsets positionPadding
final

To ensure that the tap area of ​​the coordinate point can respond to touch events even when it is at the edge, the chart itself should be padded inwards with the maximum value of the zoomed radius and the SlidableLineChart.coordinateSystemOrigin.

See _generatePositionPadding.

Implementation

final EdgeInsets positionPadding;