OnDrawIndicator typedef
Coordinate uses this callback to paint the value indicator on the overlay.
Implementation
typedef OnDrawIndicator = bool Function(double value);
Coordinate uses this callback to paint the value indicator on the overlay.
typedef OnDrawIndicator = bool Function(double value);