hitTest method

bool hitTest(
  1. Offset position
)

Tests whether a given point will be considered to hit a coordinate point.

Returns true if the user's touch point is within the range of zoomedRect, otherwise returns false.

Implementation

bool hitTest(Offset position) => zoomedRect.contains(position);