value property
Value that change as the user slides.
It is also the value displayed on the coordinate system.
Implementation
final double value;
Value that change as the user slides.
It is also the value displayed on the coordinate system.
final double value;