Coordinates<E extends Enum> class

An instance of mapped by CoordinatesOptions.

Annotations

Constructors

Coordinates({required E type, required List<Coordinate> value})
Create coordinates.
const
Coordinates.formOptions(CoordinatesOptions<E> options)
Generate a Coordinates derived from the given CoordinatesOptions.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type → E
Type of coordinates.
final
value List<Coordinate>
All coordinate point.
final

Methods

copyWith({List<Coordinate>? value}) Coordinates<E>
Creates a new Coordinates from this one by updating individual properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toOptions() CoordinatesOptions<E>
Generate a CoordinatesOptions from the current Coordinates.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override