copyWith method
Creates a new Coordinates from this one by updating individual properties.
Implementation
Coordinates<E> copyWith({List<Coordinate>? value}) => Coordinates<E>(
type: type,
value: value ?? this.value,
);
Creates a new Coordinates from this one by updating individual properties.
Coordinates<E> copyWith({List<Coordinate>? value}) => Coordinates<E>(
type: type,
value: value ?? this.value,
);