CoordinatesOptions<E extends Enum> class

Define a configuration for a set of coordinate points.

Annotations

Constructors

CoordinatesOptions(E type, {required List<double> values, double radius = kDefaultCoordinatesOptionsRadius, double zoomedFactor = kDefaultCoordinatesOptionsZoomedFactor})
Create CoordinatesOptions to add a polyline to SlidableLineChart.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
radius double
Radius of coordinate points.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type → E
Type of coordinates options.
final
values List<double>
The value displayed in the coordinate system for each coordinate point.
final
zoomedFactor double
Magnification factor of the touch area.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override