CoordinatesStyle<E extends Enum> class

The style of Coordinates.

Annotations

Constructors

CoordinatesStyle({required E type, Color? pointColor, Color? tapAreaColor, Color? lineColor, Color? fillAreaColor})
Creates a coordinates style.
const

Properties

fillAreaColor Color?
Color of fill area.
final
hashCode int
The hash code for this object.
no setteroverride
lineColor Color?
Color of coordinate line.
final
pointColor Color?
Color of coordinate point.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tapAreaColor Color?
Color of the touch area when the coordinate point is slidable.
final
type → E
Type of coordinates style.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override