displayValueMarginBottom property
Margin bottom for display value on the coordinate system.
If this value are null, then kDisplayValueMarginBottom will be used.
Implementation
final double? displayValueMarginBottom;
Margin bottom for display value on the coordinate system.
If this value are null, then kDisplayValueMarginBottom will be used.
final double? displayValueMarginBottom;