displayValueTextStyle property
Text style for display value on the coordinate system.
If this value are null, then kDisplayValueTextStyle will be used.
Implementation
final TextStyle? displayValueTextStyle;
Text style for display value on the coordinate system.
If this value are null, then kDisplayValueTextStyle will be used.
final TextStyle? displayValueTextStyle;