indicatorMarginTop property
Margin top for check or close indicator on the coordinate system.
If this value are null, then kIndicatorMarginTop will be used.
Implementation
final double? indicatorMarginTop;
Margin top for check or close indicator on the coordinate system.
If this value are null, then kIndicatorMarginTop will be used.
final double? indicatorMarginTop;