indicatorRadius property
Radius for check or close indicator on the coordinate system.
If this value are null, then kIndicatorRadius will be used.
Implementation
final double? indicatorRadius;
Radius for check or close indicator on the coordinate system.
If this value are null, then kIndicatorRadius will be used.
final double? indicatorRadius;