CoordinateSystemPainter<E extends Enum> class
CoordinateSystemPainter combines all the information to draw a line graph on the canvas.
- Inheritance
-
- Object
- Listenable
- CustomPainter
- CoordinateSystemPainter
Constructors
-
CoordinateSystemPainter({required E? slidableCoordinateType, required List<
String> xAxis, required Offset coordinateSystemOrigin, required EdgeInsets positionPadding, required int min, required int max, required int divisions, required bool reversed, required bool onlyRenderEvenAxisLabel, required bool fillWidth, required OnDrawIndicator? onDrawCheckOrClose, required List<int> yAxis, required AnimationController? slidableCoordsAnimationCtrl, required AnimationController? otherCoordsAnimationCtrl, required GetXAxisTickLineWidth getXAxisTickLineWidth, required Map<E, Coordinates< coordinatesMap, required GetYAxisTickLineHeight getYAxisTickLineHeight, required double maxOffsetValueOnYAxisSlidingArea, required SlidableLineChartThemeData<E> >E> ? slidableLineChartThemeData, required bool triggerClear}) - Creates a coordinate system painter.
Properties
-
coordinatesMap
→ Map<
E, Coordinates< E> > -
Map containing all coordinates data.
final
- coordinateSystemOrigin → Offset
-
Coordinate system origin offset value.
final
- divisions → int
-
The division value of y-axis.
final
- fillWidth → bool
-
Align the first and last points of the chart with both ends.
final
- getXAxisTickLineWidth → GetXAxisTickLineWidth
-
Get X-axis tick line width from the length of SlidableLineChart.xAxis.
final
- getYAxisTickLineHeight → GetYAxisTickLineHeight
-
Get Y-axis tick line height from the length of
_yAxis.final - hashCode → int
-
The hash code for this object.
no setterinherited
- max → int
-
The maximum value that the user can slide to.
final
- maxOffsetValueOnYAxisSlidingArea → double
-
Maximum offset on the Y-axis sliding area.
final
- min → int
-
The minimum value that the user can slide to.
final
- onDrawCheckOrClose → OnDrawIndicator?
-
Called when the user slides coordinate, the return value determines the
indicator type.
final
- onlyRenderEvenAxisLabel → bool
-
Whether the y-axis label renders only even items.
final
- otherCoordsAnimationCtrl → AnimationController?
-
Animation controller with other line chart.
final
- positionPadding → EdgeInsets
-
To ensure that the tap area of the coordinate point can respond to touch
events even when it is at the edge, the chart itself should be padded
inwards with the maximum value of the zoomed radius and the
SlidableLineChart.coordinateSystemOrigin.
final
- reversed → bool
-
Whether the coordinate system is reversed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticsBuilder → SemanticsBuilderCallback?
-
Returns a function that builds semantic information for the picture drawn
by this painter.
no setterinherited
- slidableCoordinateType → E?
-
The type of coordinates the user can slide.
final
- slidableCoordsAnimationCtrl → AnimationController?
-
Animation controller with slidable line chart.
final
-
slidableLineChartThemeData
→ SlidableLineChartThemeData<
E> ? -
Defines the configuration of the overall visual SlidableLineChartThemeData
for a SlidableLineChart.
final
- triggerClear → bool
-
The flag that triggers the cleanup animation.
final
-
xAxis
→ List<
String> -
Labels displayed on the x-axis.
final
-
yAxis
→ List<
int> -
Text display on Y-axis.
final
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be notified when it is time to repaint.
inherited
-
hitTest(
Offset position) → bool? -
Called whenever a hit test is being performed on an object that is using
this custom paint delegate.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Size size) → void -
Called whenever the object needs to paint. The given Canvas has its
coordinate space configured such that the origin is at the top left of the
box. The area of the box is the size of the
sizeargument.override -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies when it is time to repaint.
inherited
-
shouldRebuildSemantics(
covariant CustomPainter oldDelegate) → bool -
Called whenever a new instance of the custom painter delegate class is
provided to the RenderCustomPaint object, or any time that a new
CustomPaint object is created with a new instance of the custom painter
delegate class (which amounts to the same thing, because the latter is
implemented in terms of the former).
inherited
-
shouldRepaint(
covariant CoordinateSystemPainter< E> oldDelegate) → bool -
Called whenever a new instance of the custom painter delegate class is
provided to the RenderCustomPaint object, or any time that a new
CustomPaint object is created with a new instance of the custom painter
delegate class (which amounts to the same thing, because the latter is
implemented in terms of the former).
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited