triggerClear property
The flag that triggers the cleanup animation.
When _triggerClear is set to true, the reset animation controller will
trigger an animation opposite to the initialization animation. After the
reset animation is completed, the value will be reset to false.
Implementation
final bool triggerClear;