SlidableLineChartThemeData<E extends Enum> class
Defines the configuration of the overall visual SlidableLineChartThemeData for a SlidableLineChart.
- Annotations
Constructors
-
SlidableLineChartThemeData({List<
CoordinatesStyle< ? coordinatesStyleList, TextStyle? axisLabelStyle, Color? axisLineColor, double? axisLineWidth, Color? gridLineColor, double? gridLineWidth, DrawGridLineType? drawGridLineType, DrawGridLineStyle? drawGridLineStyle, double? dashedGridLineWidth, double? dashedGridLineGap, bool? showTapArea, double? lineWidth, TextStyle? displayValueTextStyle, double? displayValueMarginBottom, double? indicatorMarginTop, double? indicatorRadius, Color? checkBackgroundColor, Color? closeBackgroundColor, Color? checkColor, Color? closeColor, double? smooth, double? disabledOpacity})E> > -
Create a SlidableLineChartThemeData that's used to configure a
SlidableLineChartTheme.
const
Properties
- axisLabelStyle → TextStyle?
-
Axis label style for the coordinate system.
final
- axisLineColor → Color?
-
Axis line color for the coordinate system.
final
- axisLineWidth → double?
-
Axis line width for the coordinate system.
final
- checkBackgroundColor → Color?
-
Background color for check indicator on the coordinate system.
final
- checkColor → Color?
-
Color for check symbol on the coordinate system.
final
- closeBackgroundColor → Color?
-
Background color for close indicator on the coordinate system.
final
- closeColor → Color?
-
Color for close symbol on the coordinate system.
final
-
coordinatesStyleList
→ List<
CoordinatesStyle< ?E> > -
All coordinates style list.
final
-
coordinatesStyleMap
→ Map<
E, CoordinatesStyle< ?E> > -
Generate a Map from the current coordinatesStyleList.
no setter
- dashedGridLineGap → double?
-
The gap width of the dashed grid lines.
final
- dashedGridLineWidth → double?
-
The unit width of the dashed grid lines.
final
- disabledOpacity → double?
-
Opacity when line chart is can't change.
final
- displayValueMarginBottom → double?
-
Margin bottom for display value on the coordinate system.
final
- displayValueTextStyle → TextStyle?
-
Text style for display value on the coordinate system.
final
- drawGridLineStyle → DrawGridLineStyle?
-
The style of grid lines to draw.
final
- drawGridLineType → DrawGridLineType?
-
The type of grid lines to draw.
final
- gridLineColor → Color?
-
Grid line color for the coordinate system.
final
- gridLineWidth → double?
-
Grid line width for the coordinate system.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- indicatorMarginTop → double?
-
Margin top for check or close indicator on the coordinate system.
final
- indicatorRadius → double?
-
Radius for check or close indicator on the coordinate system.
final
- lineWidth → double?
-
Line width on the all coordinates.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showTapArea → bool?
-
Whether to display the user's touch area.
final
- smooth → double?
-
Smoothness of the line chart.
final
Methods
-
copyWith(
{List< CoordinatesStyle< ? coordinatesStyleList, TextStyle? axisLabelStyle, Color? axisLineColor, double? axisLineWidth, Color? gridLineColor, double? gridLineWidth, DrawGridLineType? drawGridLineType, DrawGridLineStyle? drawGridLineStyle, double? dashedGridLineWidth, double? dashedGridLineGap, bool? showTapArea, double? lineWidth, TextStyle? displayValueTextStyle, double? displayValueMarginBottom, double? indicatorMarginTop, double? indicatorRadius, Color? checkBackgroundColor, Color? closeBackgroundColor, Color? checkColor, Color? closeColor, double? smooth, double? disabledOpacity}) → SlidableLineChartThemeData<E> >E> - Creates a copy of this theme data but with the given fields replaced with the new values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override